(()=>{var e,o,d={},s={};function _(e){var o=s[e];if(void 0!==o)return o.exports;var t=s[e]={id:e,exports:{}};return d[e].call(t.exports,t,t.exports,_),t.exports}_.m=d,_.n=e=>{var o=e&&e.__esModule?()=>e.default:()=>e;return _.d(o,{a:o}),o},_.d=(e,o)=>{for(var d in o)_.o(o,d)&&!_.o(e,d)&&Object.defineProperty(e,d,{enumerable:!0,get:o[d]})},_.f={},_.e=e=>Promise.all(Object.keys(_.f).reduce((o,d)=>(_.f[d](e,o),o),[])),_.u=e=>"notes-"+e+".js?v="+{"vendors-node_modules_striptags_src_striptags_js-node_modules_nextcloud_vue_dist_assets_NcAvat-041429":"0177156ccb314019075b","vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vuex_dist_vuex_esm_js-no-1ceaa3":"5a6223aad2c7676d1178","dashboard-lazy":"31fee1ae054e22775aab","vendors-node_modules_nextcloud_dialogs_dist_chunks__plugin-vue_export-helper-1tPrXgE0_mjs-nod-88e649":"2f99e3a92f37e74c3ab7","vendors-node_modules_mdi_js_mdi_js-node_modules_nextcloud_dialogs_dist_chunks_preview-BIbJGxX-8a4549":"fcd8a853a807521909e8","vendors-node_modules_nextcloud_dialogs_dist_chunks_ConflictPicker-D-B-WV0C_mjs":"7f3f57603ad993c109d9","vendors-node_modules_floating-ui_dom_dist_floating-ui_dom_mjs":"d4f78cb09a0a9e23e755","vendors-node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcTextField-759f92":"fd7096b8de3f24fee99f","vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-W-IYpVkn_mjs":"2203b15fd27dfb251f10","node_modules_nextcloud_dialogs_dist_chunks_PublicAuthPrompt-uFWxS9Cy_mjs":"bb1dae8d64b3103dfbaf","vendors-node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcColorPick-2135ac":"df4f1974cf1100af30da","vendors-node_modules_nextcloud_dialogs_node_modules_nextcloud_vue_dist_components_NcDateTimeP-55190c":"c4bcc31cefb6f44e930d"}[e],_.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),_.o=(e,o)=>Object.prototype.hasOwnProperty.call(e,o),e={},o="notes:",_.l=(d,s,t,n)=>{if(e[d])e[d].push(s);else{var a,r;if(void 0!==t)for(var u=document.getElementsByTagName("script"),i=0;i<u.length;i++){var l=u[i];if(l.getAttribute("src")==d||l.getAttribute("data-webpack")==o+t){a=l;break}}a||(r=!0,(a=document.createElement("script")).charset="utf-8",_.nc&&a.setAttribute("nonce",_.nc),a.setAttribute("data-webpack",o+t),a.src=d),e[d]=[s];var c=(o,s)=>{a.onerror=a.onload=null,clearTimeout(m);var t=e[d];if(delete e[d],a.parentNode&&a.parentNode.removeChild(a),t&&t.forEach(e=>e(s)),o)return o(s)},m=setTimeout(c.bind(null,void 0,{type:"timeout",target:a}),12e4);a.onerror=c.bind(null,a.onerror),a.onload=c.bind(null,a.onload),r&&document.head.appendChild(a)}},_.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},_.p="/apps/notes/js/",(()=>{var e={dashboard:0};_.f.j=(o,d)=>{var s=_.o(e,o)?e[o]:void 0;if(0!==s)if(s)d.push(s[2]);else{var t=new Promise((d,t)=>s=e[o]=[d,t]);d.push(s[2]=t);var n=_.p+_.u(o),a=new Error;_.l(n,d=>{if(_.o(e,o)&&(0!==(s=e[o])&&(e[o]=void 0),s)){var t=d&&("load"===d.type?"missing":d.type),n=d&&d.target&&d.target.src;a.message="Loading chunk "+o+" failed.\n("+t+": "+n+")",a.name="ChunkLoadError",a.type=t,a.request=n,s[1](a)}},"chunk-"+o,o)}};var o=(o,d)=>{var s,t,[n,a,r]=d,u=0;if(n.some(o=>0!==e[o])){for(s in a)_.o(a,s)&&(_.m[s]=a[s]);if(r)r(_)}for(o&&o(d);u<n.length;u++)t=n[u],_.o(e,t)&&e[t]&&e[t][0](),e[t]=0},d=self.webpackChunknotes=self.webpackChunknotes||[];d.forEach(o.bind(null,0)),d.push=o.bind(null,d.push.bind(d))})(),_.nc=void 0,_.nc=btoa(OC.requestToken),_.p=OC.linkTo("notes","js/"),document.addEventListener("DOMContentLoaded",()=>{OCA.Dashboard.register("notes",async e=>{const{default:o}=await Promise.all([_.e("vendors-node_modules_striptags_src_striptags_js-node_modules_nextcloud_vue_dist_assets_NcAvat-041429"),_.e("vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vuex_dist_vuex_esm_js-no-1ceaa3"),_.e("dashboard-lazy")]).then(_.bind(_,5471)),{default:d}=await Promise.all([_.e("vendors-node_modules_striptags_src_striptags_js-node_modules_nextcloud_vue_dist_assets_NcAvat-041429"),_.e("vendors-node_modules_vue-material-design-icons_Plus_vue-node_modules_vuex_dist_vuex_esm_js-no-1ceaa3"),_.e("dashboard-lazy")]).then(_.bind(_,4335));o.mixin({methods:{t,n}});(new(o.extend(d))).$mount(e)})})})();
//# sourceMappingURL=notes-dashboard.js.map?v=20885a3e49d29026be9a