OC.L10N.register(
    "notes",
    {
    "Notes" : "Bilješke",
    "Reading notes from filesystem has failed." : "Čitanje bilješki iz datotečnog sustava nije uspjelo.",
    "Error" : "Pogreška",
    "New note" : "Nova bilješka",
    "Distraction-free notes and writing" : "Bilješke i pisanje bez ometanja",
    "Deleted {title}" : "Izbrisano {title}",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Izbrisana {number} bilješka","Izbrisane {number} bilješke","Izbrisano {number} bilješki"],
    "Undo Delete" : "Vrati izbrisano",
    "Note recovered" : "Bilješka je oporavljena",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Oporavljena {number} bilješka","Oporavljene {number} bilješke","Oporavljeno {number} bilješki"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Postoje nespremljene bilješke. Ako napustite stranicu, odbacit ćete sve promjene!",
    "Please see Nextcloud server log for details." : "Pojedinosti potražite u zapisniku Nextcloudovog poslužitelja.",
    "Preview" : "Pretpregled",
    "Insert image" : "Umetni sliku",
    "Shortcuts" : "Prečaci",
    "All notes" : "Sve bilješke",
    "Categories" : "Kategorije",
    "No notes yet" : "Još nema bilješki",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "Error during preparing note for deletion." : "Pogreška tijekom pripremanja bilješke za brisanje.",
    "Share" : "Share",
    "Rename" : "Rename",
    "Delete note" : "Izbriši bilješku",
    "Error from Nextcloud server: {msg}" : "Pogreška Nextcloudovog poslužitelja: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Bilješka je promijenjena u drugoj sesiji. Odaberite koju inačicu želite spremiti.",
    "Use version from server" : "Koristi verziju s poslužitelja",
    "Use current version" : "Koristi trenutnu verziju",
    "Empty note" : "Prazna bilješka",
    "Write …" : "Napiši...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Uredi",
    "Exit full screen" : "Zatvori prikaz preko cijelog zaslona",
    "Full screen" : "Prikaz preko cijelog zaslona",
    "Note is read-only. You cannot change it." : "Bilješka je samo za čitanje. Ne možete je promijeniti.",
    "Save failed. Click to retry." : "Spremanje nije uspjelo. Kliknite za ponovni pokušaj.",
    "Update conflict. Click for resolving manually." : "Nepodudaranje ažuriranja. Kliknite za ručno otklanjanje nepodudaranja.",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "This week" : "Ovaj tjedan",
    "Last week" : "Prošli tjedan",
    "This month" : "Ovaj mjesec",
    "Last month" : "Prošli mjesec",
    "Loading …" : "Učitavanje…",
    "Write down your thoughts without any distractions." : "Zapišite svoje misli bez ometanja.",
    "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
    "Organize your notes in categories." : "Organizirajte svoje bilješke po kategorijama.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
    "Note not found." : "Bilješka nije pronađena.",
    "Note is locked." : "Bilješka je zaključana.",
    "Insufficient storage." : "Nedovoljno prostora za pohranu.",
    "See JavaScript console and server log for details." : "Pojedinosti potražite u JavaScript konzoli i zapisniku poslužitelja.",
    "Updating settings has failed." : "Ažuriranje postavki nije uspjelo.",
    "Fetching notes for dashboard has failed." : "Dohvaćanje bilješki za nadzornu ploču nije uspjelo.",
    "Fetching notes has failed." : "Dohvaćanje bilješki nije uspjelo.",
    "Fetching note {id} has failed." : "Dohvaćanje bilješke {id} nije uspjelo.",
    "Refreshing note {id} has failed." : "Osvježavanje bilješke {id} nije uspjelo.",
    "Renaming note {id} has failed." : "Preimenovanje bilješke {id} nije uspjelo.",
    "Creating new note has failed." : "Stvaranje nove bilješke nije uspjelo.",
    "Saving note {id} has failed." : "Spremanje bilješke {id} nije uspjelo.",
    "Updating title for note {id} has failed." : "Ažuriranje naslova bilješke {id} nije uspjelo.",
    "Undo delete has failed for note {title}." : "Nije uspjelo vraćanje izbrisanog za bilješku {title}.",
    "Deleting note {id} has failed." : "Brisanje bilješke {id} nije uspjelo.",
    "Toggling favorite for note {id} has failed." : "Postavljanje favorita za bilješku {id} nije uspjelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Ažuriranje kategorije bilješke nije uspjelo. Može li se pisati u ciljni direktorij?",
    "Updating the category for note {id} has failed." : "Ažuriranje kategorije za bilješku {id} nije uspjelo.",
    "Uncategorized" : "Nekategorizirani",
    "Tasks" : "Zadaci",
    "Development Mode" : "Razvojni način rada",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Čini se da je aplikacija za upravljanje bilješkama instalirana iz razvojnog izvora. Instalirajte je iz trgovine aplikacija <a href=\"%1$s\">Nextcloud App Store</a>. Ako želite sami izraditi aplikaciju Notes, slijedite <a href=“%2$s“>upute za razvojne inženjere</a>."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
