OC.L10N.register(
    "notes",
    {
    "Notes" : "Užrašai",
    "Reading notes from filesystem has failed." : "Nepavyko perskaityti užrašų iš failų sistemos.",
    "Error" : "Klaida",
    "New note" : "Nauji užrašai",
    "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
    "Deleted {title}" : "{title} ištrinti",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Ištrinti {number} užrašai","Ištrinti {number} užrašai","Ištrinta {number} užrašų","Ištrinti {number} užrašai"],
    "Undo Delete" : "Atšaukti ištrynimą",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Atkurti {number} užrašai","Atkurti {number} užrašai","Atkurta {number} užrašų","Atkurti {number} užrašai"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
    "Notes settings" : "Užrašų nustatymai",
    "Please see Nextcloud server log for details." : "Išsamesnei informacijai žiūrėkite Nextcloud serverio žurnalą.",
    "Rich text" : "Raiškusis tekstas",
    "Preview" : "Peržiūra",
    "Insert link" : "Įterpti nuorodą",
    "Insert image" : "Įterpti paveikslą",
    "Switch between editor and viewer" : "Perjungti tarp redaktoriaus ir žiūryklės",
    "All notes" : "Visi užrašai",
    "Categories" : "Kategorijos",
    "No notes yet" : "Kol kas užrašų nėra",
    "Select an image" : "Pasirinkite paveikslą",
    "Wrong image" : "Neteisingas paveikslas",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Share" : "Share",
    "Rename" : "Rename",
    "Delete note" : "Ištrinti užrašus",
    "Error from Nextcloud server: {msg}" : "Klaida iš Nextcloud serverio: {msg}",
    "Use version from server" : "Naudoti versiją iš serverio",
    "Use current version" : "Naudoti esamą versiją",
    "Empty note" : "Tušti užrašai",
    "Write …" : "Rašykite…",
    "Edit" : "Taisyti",
    "Exit full screen" : "Išeiti iš viso ekrano",
    "Full screen" : "Visas ekranas",
    "Note is read-only. You cannot change it." : "Užrašai yra tik skaitymui. Jūs negalite jų keisti.",
    "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "This week" : "Šią savaitę",
    "Last week" : "Praeitą savaitę",
    "This month" : "Šį mėnesį",
    "Last month" : "Praeitą mėnesį",
    "Loading …" : "Įkeliama…",
    "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
    "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
    "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Pradėkite rašyti užrašus, spusteldami ant mygtuko „{newnote}“.",
    "Note not found." : "Užrašai nerasti.",
    "Note is locked." : "Užrašai užrakinti.",
    "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
    "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
    "Uncategorized" : "Nekategorizuoti",
    "Tasks" : "Užduotys",
    "Development Mode" : "Plėtotojo veiksena"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
